@@ -1,31 +1,36 @@
-dgl <- function(x,lambda1=0,lambda2=1,lambda3,lambda4,param="fmkl",
-  inverse.eps=1e-8,max.iterations=500)
+dgl <- function(x,lambda1=0,lambda2=NULL,lambda3=NULL,lambda4=NULL,param="fmkl",
+  lambda5=NULL,inverse.eps=1e-8,max.iterations=500)
 {
+# Tidy the parameters so gl.check.lambda will work
+lambdas <- .gl.parameter.tidy(lambda1,lambda2,lambda3,lambda4,param,lambda5)
 # Check the parameters
-if(!gl.check.lambda(lambda1,lambda2,lambda3,lambda4,param)) {
-        stop(paste("The parameter values", lambda1, lambda2, lambda3, lambda4,
+if(!gl.check.lambda(lambdas,param=param,vect=TRUE)) {
+        stop(paste("The parameter values", lambdas,
 "\ndo not produce a proper distribution with the",param,
 "parameterisation - see \ndocumentation for gl.check.lambda"))
         }
 # calculate u=F(x) numerically, then use qdgl
 # Unless x is outside the range, then density should be zero
-extreme<-qgl(c(0,1),lambda1,lambda2,lambda3,lambda4,param)
+extreme<-qgl(c(0,1),lambda1=lambdas,param=param)
 # It may be better to change this to simply  
 # (x <= extreme[2])*(x >= extreme[1])
 outside.range <- !as.logical((x<=extreme[2])*(x>=extreme[1]))
-u <- pgl(x,lambda1,lambda2,lambda3,lambda4,param,inverse.eps,
-  max.iterations)
-dens <- qdgl(u,lambda1,lambda2,lambda3,lambda4,param)
+u <- pgl(x,lambdas,param=param,inverse.eps=inverse.eps,max.iterations=max.iterations)
+dens <- qdgl(u,lambda1=lambdas,param=param)
 dens[outside.range] <- 0
 dens
 }
 
-pgl <- function(q,lambda1=0,lambda2=1,lambda3,lambda4,param="fmkl",
-    inverse.eps=1e-8,max.iterations=500)
+pgl <- function(q,lambda1=0,lambda2=NULL,lambda3=NULL,lambda4=NULL,param="fmkl",
+    lambda5=NULL,inverse.eps=1e-8,max.iterations=500)
 {
 # Thanks to Steve Su, <s.su@qut.edu.au>, for improvements to this code
+# If lambda1 is a vector, the default value for lambda2 will cause a problem.
+# I did have a warning about this, but it will occur too often to make up for the benefit, so I've deleted it.
+# Tidy the parameters so gl.check.lambda will work
+lambdas <- .gl.parameter.tidy(lambda1,lambda2,lambda3,lambda4,param,lambda5)
 # Check the parameters
-if(!gl.check.lambda(lambda1,lambda2,lambda3,lambda4,param)) {
+if(!gl.check.lambda(lambdas,param=param,vect=TRUE)) {
 	stop(paste("The parameter values", lambda1, lambda2, lambda3,lambda4,
     	"\ndo not produce a proper distribution with the",param,
     	"parameterisation - see \ndocumentation for gl.check.lambda"))
@@ -35,7 +40,7 @@ order.x<-order(q)
 xx<-sort(q) 
 # xx has the sorted data, and jr & order.x the information to get back to the
 # original order.
-extreme<-qgl(c(inverse.eps,1-inverse.eps),lambda1,lambda2,lambda3,lambda4,param)
+extreme<-qgl(c(inverse.eps,1-inverse.eps),lambda1=lambdas,param=param)
 max.e<-extreme[2]
 min.e<-extreme[1]
 ind.min<-xx<=min.e
@@ -50,27 +55,39 @@ u <- 0*q
 result <- switch(param, 
 	freimer=, # allows for alternate expressions 
 	frm=, # allows for alternate expressions 
-	FMKL=, 
-	fmkl=.C("gl_fmkl_distfunc",lambda1,lambda2,lambda3,lambda4, 
+	FMKL=, # Notes on .C call - the "numerics", lambdas and inverse.eps don't need the as.??? call as they are implicitly double
+	fmkl=.C("gl_fmkl_distfunc",lambdas[1],lambdas[2],lambdas[3],lambdas[4], 
 		as.double(0),as.double(1),inverse.eps,
 		as.integer(max.iterations),as.double(q),as.double(u),
 		as.integer(length.of.vector),PACKAGE="gld"), 
     	ramberg=, # Ramberg & Schmeiser 
     	ram=, 
     	RS=, 
-    	rs=.C("gl_rs_distfunc",lambda1,lambda2,lambda3,lambda4, 
-    		as.double(0),as.double(1),inverse.eps,max.iterations, 
-    		as.double(q),as.double(u),as.integer(length.of.vector),
+    	rs=.C("gl_rs_distfunc",lambdas[1],lambdas[2],lambdas[3],lambdas[4], 
+    		as.double(0),as.double(1),inverse.eps,
+		as.integer(max.iterations),as.double(q),as.double(u),
+		as.integer(length.of.vector),
 		PACKAGE="gld"), 
-    	stop("Error: Parameterisation must be either fmkl or rs") 
+	fm5=.C("gl_fm5_distfunc",lambdas[1],lambdas[2],lambdas[3],
+		lambdas[4],lambdas[5], 
+    		as.double(0),as.double(1),inverse.eps,
+		as.integer(max.iterations),as.double(q),as.double(u),
+		as.integer(length.of.vector),
+		PACKAGE="gld"),
+    	stop("Error: Parameterisation must be one of fmkl, fm5 or rs") 
     	) # closes "switch" 
 if (!(is.numeric(result[[1]]))){ 
 	stop("Values for quantiles outside range. This shouldn't happen") 
 } 
-u <- result[[10]] 
+if (param=="fm5") {
+	u <- result[[11]]
+	}
+else 	{
+	u <- result[[10]]
+	}
 xx[as.logical((xx<max.e)*(xx>min.e))]<-u 
 xx[ind.min]<-0 
 xx[ind.max]<-1 
 # Revert to the original order of the dataset: 
 xx[jr] 
-} 
+} 
\ No newline at end of file
